package id

import "testing"

func TestValidateID(t *testing.T) {
	tests := []struct {
		name    string
		id      string
		wantErr bool
	}{
		{
			"Correct ID #1",
			"test",
			false,
		},
		{
			"Correct ID #2",
			"test_1",
			false,
		},
		{
			"Correct ID #3",
			"test_1-2",
			false,
		},
		{
			"Fail, ID starts with number",
			"1test",
			true,
		},
		{
			"Fail, ID to long",
			"9QoulAlFbIcnQYLSudMistN1IczCWrXUTtN5EgNQJd516DN9UjXYJxieJ1RcsNcs1",
			true,
		},
		{
			"Fail, ID with symbols",
			"test!_)(&&",
			true,
		},
	}
	for _, tt := range tests {
		t.Run(tt.name, func(t *testing.T) {
			if err := ValidateID(tt.id); (err != nil) != tt.wantErr {
				t.Errorf("ValidateID() error = %v, wantErr %v", err, tt.wantErr)
			}
		})
	}
}

func TestValidateName(t *testing.T) {
	tests := []struct {
		nameTest string
		name     string
		wantErr  bool
	}{
		{
			"Correct name #1",
			"test",
			false,
		},
		{
			"Correct name #2",
			"test_1",
			false,
		},
		{
			"Correct name #3",
			"test_1-2",
			false,
		},
		{
			"Fail, name to long",
			"ChKRLdvWi0wYYPazuBXrIRtNFy96qGrhBDkuKQNd6N2DPV86IGdXVkeTjWj7qezKreIFUp9IUn03A8WJTTORHkgXAvkPuDVM8tVMcnHbR2hznooJ3gGUsXpn4uXo2QhsviHPyUKmE10GnkCOv9FgAMILNoFVHnIiSHI3cjWlGJglpS9YAMXFB1phOIRF5yol3jmPE7EeU1uZPUw9C2PChuksGsOuJQov07Zom0b13r6wOJv8PZVa4IKmjDDLGKlq1",
			true,
		},
	}
	for _, tt := range tests {
		t.Run(tt.name, func(t *testing.T) {
			if err := ValidateName(tt.name); (err != nil) != tt.wantErr {
				t.Errorf("ValidateName() error = %v, wantErr %v", err, tt.wantErr)
			}
		})
	}
}
